//Copyright (c) Victor Hurdugaci
//http://victorhurdugaci.com
//This code is licensed under the Non-Profit Open Software License version 3.0
//Full license text: http://www.opensource.org/licenses/NOSL3.0.html

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Runtime.InteropServices;
using System.Windows.Input;
using System.Windows.Controls.Primitives;

namespace ImageVisualizer.GUI
{
    /// <summary>
    /// The window that holds the image display control and which is also the debugger window
    /// </summary>
    class ImageWindow : Window
    {
        #region Constants

        private readonly double DefaultMinimumWidth = 200;
        private readonly double DefaultMinimumHeight = 200;

        private readonly double DefaultWindowWidth = 640;
        private readonly double DefaultWindowHeight = 480;

        private readonly string WindowTitle = "Debug Image Visualizer";

        #endregion

        #region Fields

        ImageDisplay _imageDisplay;

        #endregion

        #region Constructors

        public ImageWindow(System.Drawing.Image sourceImage)
            : this(new System.Drawing.Bitmap(sourceImage))
        { }

        public ImageWindow(System.Drawing.Bitmap sourceBitmap)
            : base()
        {
            _imageDisplay = new ImageDisplay(sourceBitmap);

            InitInstance();
        }

        #endregion

        #region Methods

        void InitInstance()
        {
            #region Window Properties

            this.MinWidth = DefaultMinimumWidth;
            this.MinHeight = DefaultMinimumHeight;

            this.Height = DefaultWindowHeight;
            this.Width = DefaultWindowWidth;

            this.ShowInTaskbar = false;
            this.WindowStartupLocation = System.Windows.WindowStartupLocation.CenterOwner;

            this.Title = WindowTitle;

            #endregion

            #region Event Handlers

            this.Loaded += new RoutedEventHandler(ImageWindow_Loaded);

            #endregion

            #region Window controls

            this.AddChild(_imageDisplay);

            #endregion
        }
       
        #endregion

        #region Event Handlers
        
        void ImageWindow_Loaded(object sender, RoutedEventArgs e)
        {
            WindowHelpers.DisableMinimizeBox(this);
        }

        #endregion
    }
}
